<?php

// ログファイル格納ディレクトリ
$FILEPATH = "./data/";
// 休日設定ファイル
$HOLIDAY_FILE = "./data/holiday.txt";
// ID指定ファイル
$ID_FILE = "./data/id.txt";

$HOLIDAY[0] = NULL;

function get_week($date) {

    $info = split("/",$date);

    $year = $info[0];
    $month = $info[1];
    $day = $info[2];

    $timestamp=mktime(0,0,0,$month,$day,$year);
    $iweek=date("w",$timestamp);

    switch( $iweek) {
      case 0:
        return "(日)";
        break;
      case 1:
        return "(月)";
        break;
      case 2:
        return "(火)";
        break;
      case 3:
        return "(水)";
        break;
      case 4:
        return "(木)";
        break;
      case 5:
        return "(金)";
        break;
      case 6:
        return "(土)";
        break;
      default:
        return NULL;
        break;
    }
}

// 日付の色指定
function get_color($date) {

    // 祝日ファイルを読み込み、指定された日は強制的に色変換
    $ret = check_holiday( $date );
    if( $ret ) {
      return "#FF0000";
    }

    $info = split("/",$date);

    $year = $info[0];
    $month = $info[1];
    $day = $info[2];

    $timestamp=mktime(0,0,0,$month,$day,$year);
    $iweek=date("w",$timestamp);

    switch( $iweek) {
      case 0:
        return "#FF0000";
        break;
      case 6:
        return "#0000FF";
        break;
      default:
        return "#000000";
        break;
    }
}

// 休日ファイル検索
function check_holiday( $date ){

  global $HOLIDAY_FILE;
  global $HOLIDAY;
  if( !$HOLIDAY[0] ) {
    // ファイル読み込み
    $i=0;
    $lines = file($HOLIDAY_FILE);
    while( list($line_num, $line) = each($lines) ) {
      $line = rtrim( $line );
      $HOLIDAY[$i] = $line;
      $i++;
    }
  }

  $i=0;
  while( $HOLIDAY[$i] ) {
    // 休日の検索
    $ret = strcmp( $date,$HOLIDAY[$i] );
    if( !$ret ) {
      return TRUE;
    }
    $i++;
  }
  return FALSE;
}

// 詳細情報取得(日付指定)
function get_info( $day ) {

  global $FILEPATH;

  $i=0;
  $j=0;
  while( $day[$i] ) {
    // 日付からファイル名を作成(YYYYMM.txt)
    $date = $day[$i];
    $date = str_replace("/","",$date);
    $filename_tmp = substr($date,0,6);
    $filename_tmp = $filename_tmp.".txt";

    // 基本的に若い日付から$dayに入ってくるので、1コ前を見ればOK
    $ret = strcmp($filename[$j],$filename_tmp);
    if( $ret ) {
      // 保持しているファイル名と異なる場合は保持する
      $j++;
      $filename[$j] = $filename_tmp;
    }
    $i++;
  }

  $j=1;
  $index=0;
  while($filename[$j]) {
    $datafile = $FILEPATH.$filename[$j];
    // ファイルが存在しない場合はスキップ
    if( !file_exists($datafile) ) {
      $j++;
      continue;
    }
    // ファイル読み込み
    $lines = file($FILEPATH.$filename[$j]);
    while( list($line_num, $line) = each($lines) ) {
      $line = rtrim( $line );
      // 行の分割
      $line_info = split("<>",$line);
      $i=0;
      while( $day[$i] ) {
        $ret = strcmp($day[$i],$line_info[1]);
        if( !$ret ) {
          // 日付が一致した場合のみ保持
          $info[$index] = $line;
          $index++;
        }
        $i++;
      }
    }
    $j++;
  }
  return $info;
}

// 詳細情報取得(ID指定)
function get_detail_info( $id,$date ) {

  global $FILEPATH;

  $i=0;
  $j=0;
  // 日付からファイル名を作成(YYYYMM.txt)
  $filename = substr($date,0,6);
  $filename = $filename.".txt";

  $i=0;
  $index=0;

  $datafile = $FILEPATH.$filename;
  // ファイルが存在しない場合は空を返却
  if( !file_exists($datafile) ) {
    return NULL;
  }
  // ファイル読み込み
  $lines = file($FILEPATH.$filename);
  while( list($line_num, $line) = each($lines) ) {
    $line = rtrim( $line );
    // 行の分割
    $line_info = split("<>",$line);
    if( $id == $line_info[0]) {
      return $line;
    }
  }
  return NULL;
}

// 詳細情報表示
function print_infomation( $days, $type ) {

  $info = get_info($days);

  $i=0;
  while( $days[$i] ) {
    // 曜日取得
    $week = get_week($days[$i]);
    $color = get_color($days[$i]);
    echo "<font color='".$color."'><u>".$days[$i].$week."</u></font>";
    $today = date('Y/m/d');
    $ret = strcmp($today,$days[$i]);
    if( !$ret ) {
      echo "<a href name='today'>";
    }
    echo "<br>";
    echo "<ul>";
    $j=0;
    while( $info[$j] ) {
      $line_info = split("<>",$info[$j]);
      $ret = strcmp($days[$i],$line_info[1]);
      if( !$ret ) {
        $title = $line_info[2];
        $target_day = str_replace("/","",$days[$i]);
        $link = "<a href='./detail.php?id=".$line_info[0]."&target=".$target_day."&type=".$type."'>".$title."</a>";
        echo "<li>".$link;
      }
      $j++;
    }
    echo "</ul>";
    //echo "<hr>";
    $i++;
  }

}

// 日付形式のチェック
function check_date($i,$type) {

  $ret = is_numeric($i);
  if( !$ret ) {
    return FALSE;
  }

  switch( $type ) {
    case 'Y': // year
      if( $i < 1980 || $i > 2100 ) {
        return FALSE;
      }
      break;
    case 'M': // month
      if( $i < 1 || $i > 12 ) {
        return FALSE;
      }
      break;
    case 'D': // day
      if( $i < 1 || $i > 31 ) {
        return FALSE;
      }
      break;
    default:
      return FALSE;
  }
  return TRUE;
}


// 新規登録
function add_schedule( $year,$month,$day,$title,$detail,$url ) {

  global $FILEPATH;

  $ret = strcmp($url,'http://');
  if( !$ret ) {
    $url = '';
  }

  // 入力文字の変換
  $title = mb_convert_encoding($title,"UTF-8","auto");
  $title = htmlentities($title,ENT_QUOTES,"UTF-8");
  $title = stripslashes($title);
  $detail = mb_convert_encoding($detail,"UTF-8","auto");
  $detail = htmlentities($detail,ENT_QUOTES,"UTF-8");
  $detail = stripslashes($detail);
  $detail = str_replace("\r\n","<br>",$detail);

  $url = mb_convert_encoding($url,"UTF-8","auto");
  $url = urldecode( $url );

  
  $date = sprintf("%04d/%02d/%02d", $year,$month,$day);
  $id = get_id();

  // #ID<>Date<>Title<>Detail<>URL
  $line = $id."<>".$date."<>".$title."<>".$detail."<>".$url."\r\n";
  $filename = sprintf("%04d%02d.txt",$year,$month);
  $filename = $FILEPATH.$filename;

  $fp = fopen($filename, "a");
  fputs($fp,$line);
  fclose($fp);

  return $id;
}


// 削除
function del_schedule($id, $target) {

  global $FILEPATH;

  $year = substr($target,0,4);
  $month = substr($target,4,2);

  $filename = sprintf("%04d%02d.txt",$year,$month);
  $filename = $FILEPATH.$filename;

  $lines = file($filename);
  while( list($line_num, $line) = each($lines) ) {

    $tmp = split("<>",$line);
    if( $id != $tmp[0] ) {
      $new .= $line;
    }
  }
  $fp = fopen($filename,"w");
  fputs($fp,$new);
  fclose($fp);
}


// 新規追加時のID取得
function get_id() {

  global $ID_FILE;

  // 現在のID取得
  $line = file($ID_FILE);
  $id = rtrim( $line[0] );
  $id++;

  // 新規IDを書き込み
  $fp = fopen($ID_FILE,"w");
  fputs($fp,$id);
  fclose($fp);

  return $id;

}

?>
